@@ -218,8 +218,8 @@ class BaseXmlModel(pd.BaseModel, metaclass=XmlModelMeta):
             tag: Optional[str] = None,
             ns: Optional[str] = None,
             nsmap: Optional[NsMap] = None,
-            ns_attrs: bool = False,
-            search_mode: SearchMode = SearchMode.STRICT,
+            ns_attrs: Optional[bool] = None,
+            search_mode: Optional[SearchMode] = None,
             **kwargs: Any,
     ):
         """
@@ -237,8 +237,9 @@ class BaseXmlModel(pd.BaseModel, metaclass=XmlModelMeta):
         cls.__xml_tag__ = tag if tag is not None else getattr(cls, '__xml_tag__', None)
         cls.__xml_ns__ = ns if ns is not None else getattr(cls, '__xml_ns__', None)
         cls.__xml_nsmap__ = nsmap if nsmap is not None else getattr(cls, '__xml_nsmap__', None)
-        cls.__xml_ns_attrs__ = ns_attrs if ns_attrs is not None else getattr(cls, '__xml_ns_attrs__', None)
-        cls.__xml_search_mode__ = search_mode if search_mode is not None else getattr(cls, '__xml_search_mode__', None)
+        cls.__xml_ns_attrs__ = ns_attrs if ns_attrs is not None else getattr(cls, '__xml_ns_attrs__', False)
+        cls.__xml_search_mode__ = search_mode if search_mode is not None \
+            else getattr(cls, '__xml_search_mode__', SearchMode.STRICT)
 
         default_xml_encoder: Callable[[Any], Any]
         if xml_encoders := getattr(cls.Config, 'xml_encoders', None):
